@@ -5,7 +5,7 @@ import re
 import shutil
 import subprocess
 import urllib.request
-from typing import Any, List, NamedTuple
+from typing import Any, List, NamedTuple, Optional, Set
 
 import bs4
 import click
@@ -187,6 +187,37 @@ def install_vscode(version: str) -> None:
         icon_file.write(icon_data)
 
 
+def get_installed_versions() -> Set[str]:
+    """Returns all vscode versions installed on the system"""
+    installed_versions: Set[str] = set()
+
+    version_regex = re.compile(r"\d+\.\d+")
+    for folder in os.listdir(VSCVM_PATH):
+        if version_regex.match(folder):
+            installed_versions.add(folder)
+
+    return installed_versions
+
+
+def get_active_version() -> Optional[str]:
+    """Returns currently active vscode version, or None"""
+    script_file_path = os.path.join(VSCVM_PATH, "code")
+    if not os.path.isfile(script_file_path):
+        return None
+
+    with open(script_file_path) as script_file:
+        script_data = script_file.read()
+
+    script_regex = re.compile(r"/home/.+/\.vscvm/(\d+\.\d+)")
+    match = script_regex.match(script_data)
+
+    if match is None:
+        return None
+
+    (version,) = match.groups()
+    return version
+
+
 @click.group()
 def cli() -> None:
     """VSCode version manager"""
@@ -194,10 +225,31 @@ def cli() -> None:
 
 @cli.command()
 @click.option("--count", "-n", default=5, help="Number of versions to show")
-def list(count: int) -> None:
+@click.option("--installed", is_flag=True, help="Only show installed versions")
+@click.option("--active", is_flag=True, help="Only show currently active version")
+def list(count: int, installed: bool, active: bool) -> None:
     """List all VSCode versions"""
+    active_version = get_active_version()
+    installed_versions = get_installed_versions()
     for _, version, month in get_vscode_versions()[:count]:
-        print(f"v{version} - {month}")
+        if version == active_version:
+            status = "[Active]"
+
+        elif version in installed_versions:
+            # If --active flag was passed, don't print this one
+            if active:
+                continue
+
+            status = "[Installed]"
+
+        else:
+            # If installed or active flag was passed, don't print this one
+            if active or installed:
+                continue
+
+            status = ""
+
+        print(f"v{version:5} - {month:14} {status}")
 
 
 @cli.command()
@@ -224,16 +276,36 @@ def install(version: str) -> None:
 
 
 @cli.command()
-@click.argument("version")
+@click.argument("version", default="")
 def uninstall(version: str) -> None:
     """Uninstall a VSCode versions"""
     version = version.lstrip("v")
+
+    if version == "":
+        active_version = get_active_version()
+        if active_version is None:
+            print("No active VSCode version found. Aborting.")
+            return
+
+        version = active_version
+
+    version = version.lstrip("v")
     version_path = os.path.join(VSCVM_PATH, version)
     if not os.path.exists(version_path):
-        print(f"v{version} does not exist in installed versions.")
+        print(f"{version} does not exist in installed versions.")
         return
 
     shutil.rmtree(version_path)
+
+    active_version = get_active_version()
+    if version == active_version:
+        script_file_path = os.path.join(VSCVM_PATH, "code")
+        os.remove(script_file_path)
+
+        launcher_file = os.path.expanduser("~/.local/share/applications/code.desktop")
+        if os.path.exists(launcher_file):
+            os.remove(launcher_file)
+
     print(f"Uninstalled v{version}.")
 
 
